@@ -1726,8 +1726,6 @@ class Commands:
 
     def clear_assert(self) -> [bytes]:
 
-        print('CLEARING ASSERTS')
-
         self._reset_buffer()
 
         set_default_mission_command = b'CLEARASSERT\r\n'
@@ -1802,8 +1800,6 @@ class Commands:
 
         listfiles_command += b'\r\n'
 
-        print('LISTFILES COMMAND: {}'.format(listfiles_command))
-
         self.connection.write(listfiles_command)
 
         get_reply = self._handle_reply(command=listfiles_command, terminator=b'OK\r\n', timeout=10)
