@@ -1,7 +1,4 @@
-#from logging import info, warning, error
-import logging
 
-logger = logging.getLogger()
 
 class Messages:
 
